==> jc-1.4.0.tar.gz: javax/swing/event/TableModelEvent.h <==
// public class javax.swing.event.TableModelEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 549e3501cfd5023e javax_swing_event_TableModelEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TableModelEvent_H_
#define _JC_javax_swing_event_TableModelEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_TableModel$object;

// Typedefs
typedef struct _jc_javax_swing_event_TableModelEvent$sub_refs	_jc_javax_swing_event_TableModelEvent$sub_refs;
typedef struct _jc_javax_swing_event_TableModelEvent$sub_nonrefs	_jc_javax_swing_event_TableModelEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TableModelEvent$refs	_jc_javax_swing_event_TableModelEvent$refs;
typedef struct _jc_javax_swing_event_TableModelEvent$nonrefs	_jc_javax_swing_event_TableModelEvent$nonrefs;
typedef struct _jc_javax_swing_event_TableModelEvent$object	_jc_javax_swing_event_TableModelEvent$object;

typedef struct _jc_javax_swing_event_TableModelEvent$fields_struct	_jc_javax_swing_event_TableModelEvent$fields_struct;
typedef const struct _jc_javax_swing_event_TableModelEvent$vmethods	_jc_javax_swing_event_TableModelEvent$vmethods;
typedef const struct _jc_javax_swing_event_TableModelEvent$vtable	_jc_javax_swing_event_TableModelEvent$vtable;
typedef const struct _jc_javax_swing_event_TableModelEvent$vtype	_jc_javax_swing_event_TableModelEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_TableModelEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ALL__5fCOLUMNS;
	jint	DELETE;
	jint	HEADER__5fROW;
	jint	INSERT;
	jint	UPDATE;
};
extern _jc_javax_swing_event_TableModelEvent$fields_struct _jc_javax_swing_event_TableModelEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_TableModelEvent$method$_init$9919d18d730c3a22(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *);
extern void _jc_javax_swing_event_TableModelEvent$method$_init$a09eea7743db30b4(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint);
extern void _jc_javax_swing_event_TableModelEvent$method$_init$3e93f74af771dc13(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint);
extern void _jc_javax_swing_event_TableModelEvent$method$_init$414118262c6cdfcd(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint, jint);
extern void _jc_javax_swing_event_TableModelEvent$method$_init$8965d0f663c97e11(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint, jint, jint);

// Virtual methods
extern jint _jc_javax_swing_event_TableModelEvent$method$getColumn$21002eea38f83ab4(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
extern jint _jc_javax_swing_event_TableModelEvent$method$getFirstRow$95ed55215559af3c(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
extern jint _jc_javax_swing_event_TableModelEvent$method$getLastRow$5958f298c6ea919b(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
extern jint _jc_javax_swing_event_TableModelEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
extern void _jc_javax_swing_event_TableModelEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getColumn$21002eea38f83ab4;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getFirstRow$95ed55215559af3c;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getLastRow$5958f298c6ea919b;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TableModelEvent$vmethods {
	jint	(*getColumn$21002eea38f83ab4)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
	jint	(*getFirstRow$95ed55215559af3c)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
	jint	(*getLastRow$5958f298c6ea919b)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_TableModelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TableModelEvent$vmethods	javax_swing_event_TableModelEvent;
};

// Vtype
struct _jc_javax_swing_event_TableModelEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TableModelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TableModelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TableModelEvent$refs {
    _jc_javax_swing_event_TableModelEvent$sub_refs	javax_swing_event_TableModelEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TableModelEvent$sub_nonrefs {
	jint	column;
	jint	firstRow;
	jint	lastRow;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TableModelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TableModelEvent$sub_nonrefs	javax_swing_event_TableModelEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TableModelEvent$object {
	_jc_javax_swing_event_TableModelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TableModelEvent$vtype	*vtype;
	_jc_javax_swing_event_TableModelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TableModelEvent$vtype _jc_javax_swing_event_TableModelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TableModelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TableModelEvent$class_object;

#endif	/* _JC_javax_swing_event_TableModelEvent_H_ */

==> jc-1.4.5.tar.gz: javax/swing/event/TableModelEvent.h <==
// public class javax.swing.event.TableModelEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 549e3501cfd5023e javax_swing_event_TableModelEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TableModelEvent_H_
#define _JC_javax_swing_event_TableModelEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_TableModel$object;

// Typedefs
typedef struct _jc_javax_swing_event_TableModelEvent$sub_refs	_jc_javax_swing_event_TableModelEvent$sub_refs;
typedef struct _jc_javax_swing_event_TableModelEvent$sub_nonrefs	_jc_javax_swing_event_TableModelEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TableModelEvent$refs	_jc_javax_swing_event_TableModelEvent$refs;
typedef struct _jc_javax_swing_event_TableModelEvent$nonrefs	_jc_javax_swing_event_TableModelEvent$nonrefs;
typedef struct _jc_javax_swing_event_TableModelEvent$object	_jc_javax_swing_event_TableModelEvent$object;

typedef struct _jc_javax_swing_event_TableModelEvent$fields_struct	_jc_javax_swing_event_TableModelEvent$fields_struct;
typedef const struct _jc_javax_swing_event_TableModelEvent$vmethods	_jc_javax_swing_event_TableModelEvent$vmethods;
typedef const struct _jc_javax_swing_event_TableModelEvent$vtable	_jc_javax_swing_event_TableModelEvent$vtable;
typedef const struct _jc_javax_swing_event_TableModelEvent$vtype	_jc_javax_swing_event_TableModelEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_TableModelEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ALL__5fCOLUMNS;
	jint	DELETE;
	jint	HEADER__5fROW;
	jint	INSERT;
	jint	UPDATE;
};
extern _jc_javax_swing_event_TableModelEvent$fields_struct _jc_javax_swing_event_TableModelEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_TableModelEvent$method$_init$9919d18d730c3a22(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableModelEvent$method$_init$a09eea7743db30b4(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableModelEvent$method$_init$3e93f74af771dc13(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableModelEvent$method$_init$414118262c6cdfcd(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableModelEvent$method$_init$8965d0f663c97e11(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *, struct _jc_object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_event_TableModelEvent$method$getColumn$21002eea38f83ab4(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_TableModelEvent$method$getFirstRow$95ed55215559af3c(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_TableModelEvent$method$getLastRow$5958f298c6ea919b(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_TableModelEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableModelEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getColumn$21002eea38f83ab4;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getFirstRow$95ed55215559af3c;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getLastRow$5958f298c6ea919b;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_javax_swing_event_TableModelEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TableModelEvent$vmethods {
	jint	(*getColumn$21002eea38f83ab4)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getFirstRow$95ed55215559af3c)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getLastRow$5958f298c6ea919b)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TableModelEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_TableModelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TableModelEvent$vmethods	javax_swing_event_TableModelEvent;
};

// Vtype
struct _jc_javax_swing_event_TableModelEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TableModelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TableModelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TableModelEvent$refs {
    _jc_javax_swing_event_TableModelEvent$sub_refs	javax_swing_event_TableModelEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TableModelEvent$sub_nonrefs {
	jint	column;
	jint	firstRow;
	jint	lastRow;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TableModelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TableModelEvent$sub_nonrefs	javax_swing_event_TableModelEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TableModelEvent$object {
	_jc_javax_swing_event_TableModelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TableModelEvent$vtype	*vtype;
	_jc_javax_swing_event_TableModelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TableModelEvent$vtype _jc_javax_swing_event_TableModelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TableModelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TableModelEvent$class_object;

#endif	/* _JC_javax_swing_event_TableModelEvent_H_ */
